import { FrameData } from "framesync";
import { Action } from "popmotion";
export declare type Transformer<T> = (v: T) => T;
export declare type Subscriber<T> = (v: T) => void;
export declare type Config<T> = {
    transformer?: Transformer<T>;
    parent?: MotionValue<T>;
};
export declare type ActionConfig = {
    [key: string]: any;
};
export declare type ActionFactory = (actionConfig: ActionConfig) => Action;
export declare class MotionValue<V = any> {
    private current;
    private prev;
    private timeDelta;
    private lastUpdated;
    private children;
    private parent?;
    private updateSubscribers;
    private renderSubscribers;
    private cancelSubscriber;
    private transformer?;
    private controller?;
    private canTrackVelocity;
    constructor(init: V, { transformer, parent }?: Config<V>);
    addChild(config: Config<V>): MotionValue<V>;
    removeChild(child: MotionValue): void;
    addUpdateSubscription(subscription: Subscriber<V>): () => boolean;
    addRenderSubscription(subscription: Subscriber<V>): () => boolean;
    set(v: V, render?: boolean): void;
    notifySubscriber: (subscriber: Subscriber<V>) => void;
    scheduleVelocityCheck: () => import("framesync/lib/types").Process;
    velocityCheck: ({ timestamp }: FrameData) => void;
    setChild: (child: MotionValue<any>) => void;
    get(): V;
    getVelocity(): number;
    control(controller: ActionFactory, { delay, ...config }: ActionConfig, transformer?: Transformer<V>): Promise<{}>;
    stop(): void;
    destroy(): void;
}
export declare const motionValue: <V>(init: V, opts?: Config<V> | undefined) => MotionValue<V>;
